/*
  This file is part of Calimero, a pure Java library
  for KNX network access and management.
  http://calimero.sourceforge.net

  Calimero was developed at the Vienna University of Technology,
  Automation Systems Group.
  http://www.auto.tuwien.ac.at/a-lab

  Copyright 2007 Boris Malinowsky

  This version is made available for evaluation purposes only.
  Any commercial use is prohibited. This code is preliminary and
  subject to change at any time without further notice.
  All rights reserved.
*/

/*
 $Log: FrameEvent.java,v $
 Revision 1.2  2007/07/20 00:51:57  bm
 review with small updates

 Revision 1.1  2007/02/07 01:59:28  bm
 initial commit

 */

package tuwien.auto.calimero;

import java.util.EventObject;

import tuwien.auto.calimero.cemi.CEMI;

/**
 * Event to communicate the arrival of a new cEMI frame.
 * <p>
 * 
 * @see tuwien.auto.calimero.KNXListener
 */
public class FrameEvent extends EventObject
{
	private static final long serialVersionUID = 1L;

	private final CEMI f;

	/**
	 * Creates a new frame event for <code>frame</code>.
	 * <p>
	 * 
	 * @param source the creator of this event
	 * @param frame cEMI frame
	 */
	public FrameEvent(Object source, CEMI frame)
	{
		super(source);
		f = frame;
	}

	/**
	 * Returns the cEMI frame.
	 * <p>
	 * 
	 * @return cEMI frame object
	 */
	public CEMI getFrame()
	{
		return f;
	}
}
