/*
  This file is part of Calimero, a pure Java library
  for KNX network access and management.
  http://calimero.sourceforge.net

  Calimero was developed at the Vienna University of Technology,
  Automation Systems Group.
  http://www.auto.tuwien.ac.at/a-lab

  Copyright 2007 Boris Malinowsky

  This version is made available for evaluation purposes only.
  Any commercial use is prohibited. This code is preliminary and
  subject to change at any time without further notice.
  All rights reserved.
*/

/*
 $Log$
 */

package tuwien.auto.calimero;

/**
 * @author bm
 */
public final class Settings
{
	private static final String version = "2.0.0-alpha";
	private static final String calimero = "Calimero 2.0";

	private static final String tuwien = "Vienna University of Technology";
	private static final String group = "Automation Systems Group";
	private static final String copyright = "(C) 2007";

	// aligns the bundle package name following the friendly name,
	// works for friendly name with max length of 20 chars
	private static final String bundleAlignment = "                    ";
	private static final String sep = System.getProperty("line.separator");

	private static final ClassLoader cl = ClassLoader.getSystemClassLoader();

	private Settings()
	{}

	public static String getLibraryVersion()
	{
		return version;
	}

	public static String getLibraryHeader()
	{
		final StringBuffer buf = new StringBuffer();
		buf.append(calimero + sep);
		buf.append("version " + version + sep);
		buf.append(tuwien + sep);
		buf.append(group + sep);
		buf.append(copyright);
		return buf.toString();
	}

	public static String getBundleListing()
	{
		final StringBuffer buf = new StringBuffer();
		buf.append(getBundle("cache", "tuwien.auto.calimero.cache.Cache", 1) + sep);
		buf.append(getBundle("cEMI", "tuwien.auto.calimero.cemi.CEMI", 1) + sep);
		buf
			.append(getBundle("data points", "tuwien.auto.calimero.datapoint.Datapoint",
				1)
				+ sep);
		buf.append(getBundle("DPT translator",
			"tuwien.auto.calimero.dptxlator.DPTXlator", 1)
			+ sep);
		buf.append(getBundle("KNXnet/IP",
			"tuwien.auto.calimero.knxnetip.KNXnetIPConnection", 1)
			+ sep);
		buf.append(getBundle("KNX network link",
			"tuwien.auto.calimero.link.KNXNetworkLink", 1)
			+ sep);
		buf.append(getBundle("log service", "tuwien.auto.calimero.log.LogService", 1)
			+ sep);
		buf.append(getBundle("management", "tuwien.auto.calimero.mgmt.ManagementClient",
			1)
			+ sep);
		buf.append(getBundle("process", "tuwien.auto.calimero.process."
			+ "ProcessCommunicator", 1)
			+ sep);
		buf.append(getBundle("XML", "tuwien.auto.calimero.xml.def.DefaultXMLReader", 2));
		return buf.toString();
	}

	public static void main(String[] args)
	{
		if (args.length > 0 && (args[0].equals("-version") || args[0].equals("-v")))
			out(calimero + " version " + version);
		else {
			out(getLibraryHeader());
			out("available bundles:");
			out(getBundleListing());
		}
	}

	// for now, this works by loading one class as representative from a bundle
	// to check availability, then class name is truncated to bundle id
	private static String getBundle(String friendlyName, String className, int truncate)
	{
		try {
			cl.loadClass(className);
			int start = className.length();
			for (int i = 0; i < truncate; ++i)
				start = className.lastIndexOf('.', start - 1);
			final String bundle = className.substring(0, start);
			return " + " + friendlyName + align(friendlyName) + "- " + bundle;
		}
		catch (final ClassNotFoundException e) {}
		catch (final NoClassDefFoundError e) {}
		return " - " + friendlyName + align(friendlyName) + "- not available";
	}

	private static String align(String friendlyName)
	{
		return bundleAlignment.substring(friendlyName.length());
	}

	private static void out(String s)
	{
		System.out.println(s);
	}
}
