/*
  This file is part of Calimero, a pure Java library
  for KNX network access and management.
  http://calimero.sourceforge.net

  Calimero was developed at the Vienna University of Technology,
  Automation Systems Group.
  http://www.auto.tuwien.ac.at/a-lab

  Copyright 2007 Boris Malinowsky

  This version is made available for evaluation purposes only.
  Any commercial use is prohibited. This code is preliminary and
  subject to change at any time without further notice.
  All rights reserved.
*/

/*
 $Log: StatisticImpl.java,v $
 Revision 1.2  2007/07/14 21:03:50  bm
 added API specification comments

 Revision 1.1  2007/04/13 13:09:58  bm
 added statistic implementation for caches

 */

package tuwien.auto.calimero.cache;

import tuwien.auto.calimero.cache.Cache.Statistic;

/**
 * Provide basic {@link Cache} information as required by {@link Cache.Statistic}.
 * <p>
 * 
 * @author bm
 * @see Cache.Statistic
 */
public class StatisticImpl implements Statistic
{
	private final long hits;
	private final long misses;

	/**
	 * Creates an instance and fills it with data.
	 * <p>
	 * 
	 * @param hits cache hit count
	 * @param misses cache miss count
	 */
	public StatisticImpl(final long hits, final long misses)
	{
		this.hits = hits;
		this.misses = misses;
	}

	/* (non-Javadoc)
	 * @see tuwien.auto.calimero.cache.Cache.Statistic#hitRatio()
	 */
	public final double hitRatio()
	{
		final double total = hits + misses;
		return total == 0.0 ? 0.0 : hits / total;
	}

	/* (non-Javadoc)
	 * @see tuwien.auto.calimero.cache.Cache.Statistic#hits()
	 */
	public final long hits()
	{
		return hits;
	}

	/* (non-Javadoc)
	 * @see tuwien.auto.calimero.cache.Cache.Statistic#misses()
	 */
	public final long misses()
	{
		return misses;
	}
}
