/*
  This file is part of Calimero, a pure Java library
  for KNX network access and management.
  http://calimero.sourceforge.net

  Calimero was developed at the Vienna University of Technology,
  Automation Systems Group.
  http://www.auto.tuwien.ac.at/a-lab

  Copyright 2007 Boris Malinowsky

  This version is made available for evaluation purposes only.
  Any commercial use is prohibited. This code is preliminary and
  subject to change at any time without further notice.
  All rights reserved.
*/

/*
 $Log: CEMI.java,v $
 Revision 1.2  2007/07/14 21:11:15  bm
 CVS history cleanup due to package renaming

 Revision 1.1  2007/07/14 21:08:41  bm
 added API specification comments
 
 */

package tuwien.auto.calimero.cemi;

/**
 * Common External Message Interface (cEMI).
 * <p>
 * Acts as basic interface to the cEMI ADT.<br>
 * The cEMI message format aims to be a frame structure for KNX information transport
 * independent of various KNX media.
 * 
 * @author bernhard erb
 * @author bm
 */
public interface CEMI
{
	/**
	 * Returns the data-part of the cEMI message.
	 * <p>
	 * In general, the term data-part refers to that content of the cEMI frame, which is
	 * not interpreted or parsed by subtypes of {@link CEMI}.
	 * 
	 * @return subset of frame data as byte array
	 */
	byte[] getData();

	/**
	 * Returns the cEMI message code.
	 * <p>
	 * The codes of the different cEMI message types can be looked up in the according
	 * subtype implementations.
	 * 
	 * @return the message code byte
	 */
	short getMessageCode();

	/**
	 * Returns the length of the cEMI message frame.
	 * <p>
	 * 
	 * @return the message length in bytes
	 */
	short getStructLength();

	/**
	 * Returns the byte representation of the whole cEMI message structure.
	 * <p>
	 * 
	 * @return frame as byte array
	 */
	byte[] toByteArray();
}
