/*
  This file is part of Calimero, a pure Java library
  for KNX network access and management.
  http://calimero.sourceforge.net

  Calimero was developed at the Vienna University of Technology,
  Automation Systems Group.
  http://www.auto.tuwien.ac.at/a-lab

  Copyright 2007 Boris Malinowsky

  This version is made available for evaluation purposes only.
  Any commercial use is prohibited. This code is preliminary and
  subject to change at any time without further notice.
  All rights reserved.
*/

/*
 $Log: CEMIFactory.java,v $
 Revision 1.1  2007/07/14 21:08:41  bm
 added API specification comments

 */

package tuwien.auto.calimero.cemi;

import tuwien.auto.calimero.exception.KNXFormatException;

/**
 * Factory helper for creating cEMI messages.
 * <p>
 * 
 * @author bm
 */
public final class CEMIFactory
{
	private CEMIFactory()
	{}

	/**
	 * Creates a {@link CEMI} type out of the given <code>data</code> byte stream.
	 * <p>
	 * 
	 * @param data byte stream containing a cEMI message frame structure
	 * @param offset start offset of cEMI message in <code>data</code>
	 * @param length length in bytes of the whole cEMI message in <code>data</code>
	 * @return the new created cEMI message
	 * @throws KNXFormatException if no (valid) cEMI structure was found or cEMI message
	 *         type is not supported
	 */
	public static CEMI create(byte[] data, int offset, int length)
		throws KNXFormatException
	{
		if (length < 1)
			throw new KNXFormatException("buffer too short for cEMI frame", length);
		final int mc = data[offset] & 0xff;
		switch (mc) {
		case CEMILData.MC_LDATA_REQ:
		case CEMILData.MC_LDATA_CON:
		case CEMILData.MC_LDATA_IND:
			return length < 26 ? new CEMILData(data, offset) : new CEMILDataEx(data,
				offset);
		case CEMIDevMgmt.MC_PROPREAD_REQ:
		case CEMIDevMgmt.MC_PROPREAD_CON:
		case CEMIDevMgmt.MC_PROPWRITE_REQ:
		case CEMIDevMgmt.MC_PROPWRITE_CON:
		case CEMIDevMgmt.MC_PROPINFO_IND:
		case CEMIDevMgmt.MC_RESET_REQ:
		case CEMIDevMgmt.MC_RESET_IND:
			return new CEMIDevMgmt(data, offset, length);
		case CEMIBusMon.MC_BUSMON_IND:
			return new CEMIBusMon(data, offset, length);
		default:
			throw new KNXFormatException("not supported cEMI msg code", mc);
		}
	}
}
