/*
  This file is part of Calimero, a pure Java library
  for KNX network access and management.
  http://calimero.sourceforge.net

  Calimero was developed at the Vienna University of Technology,
  Automation Systems Group.
  http://www.auto.tuwien.ac.at/a-lab

  Copyright 2007 Boris Malinowsky

  This version is made available for evaluation purposes only.
  Any commercial use is prohibited. This code is preliminary and
  subject to change at any time without further notice.
  All rights reserved.
*/

/*
 $Log: KNXFormatException.java,v $
 Revision 1.1  2007/07/15 00:56:40  bm
 initial commit after package renaming

 Revision 1.2  2007/03/21 00:38:25  bm
 minor stylistic changes

 Revision 1.1  2007/03/20 13:47:28  bm
 Introduced exception hierarchy
 with basic error types

 */

package tuwien.auto.calimero.exception;

/**
 * Thrown when some value or content is not in accordance with the expected or requested
 * format or result.
 * <p>
 * 
 * @author bm
 */
public class KNXFormatException extends KNXException
{
	private static final long serialVersionUID = 1L;

	private final String item;

	/**
	 * Constructs a <code>KNXFormatException</code> without a detail message.
	 * <p>
	 */
	public KNXFormatException()
	{
		item = null;
	}

	/**
	 * Constructs a <code>KNXFormatException</code> with the specified detail message.
	 * <p>
	 * 
	 * @param s the detail message
	 */
	public KNXFormatException(String s)
	{
		super(s);
		item = null;
	}

	/**
	 * Constructs a <code>KNXFormatException</code> with the specified detail message
	 * and the invalid item.
	 * <p>
	 * 
	 * @param s the detail message
	 * @param item value, content or piece of information causing this exception (allowed
	 *        to be <code>null</code>)
	 */
	public KNXFormatException(String s, String item)
	{
		super(s);
		this.item = item;
	}

	/**
	 * Constructs a <code>KNXFormatException</code> with the specified detail message
	 * and the invalid item value of type int.
	 * <p>
	 * The <code>item</code> value is formatted into a hexadecimal string representation
	 * using the format "0x" prefix + value (e.g. "0x23" for an item value of 23).
	 * 
	 * @param s the detail message
	 * @param item the value causing this exception
	 */
	public KNXFormatException(String s, int item)
	{
		super(s);
		this.item = "0x" + Integer.toHexString(item);
	}

	/**
	 * Returns the value, content or piece of information which caused the exception.
	 * <p>
	 * 
	 * @return item representation as string, or <code>null</code> if no item was set
	 */
	public final String getItem()
	{
		return item;
	}
}
