/*
  This file is part of Calimero, a pure Java library
  for KNX network access and management.
  http://calimero.sourceforge.net

  Calimero was developed at the Vienna University of Technology,
  Automation Systems Group.
  http://www.auto.tuwien.ac.at/a-lab

  Copyright 2007 Boris Malinowsky

  This version is made available for evaluation purposes only.
  Any commercial use is prohibited. This code is preliminary and
  subject to change at any time without further notice.
  All rights reserved.
*/

/*
 $Log: KNXIllegalArgumentException.java,v $
 Revision 1.1  2007/07/15 00:56:40  bm
 initial commit after package renaming

 Revision 1.2  2007/03/21 00:38:25  bm
 minor stylistic changes

 Revision 1.1  2007/03/20 13:47:28  bm
 Introduced exception hierarchy
 with basic error types

 */

package tuwien.auto.calimero.exception;

/**
 * Thrown to indicate that a method has been passed an illegal or inappropriate argument.
 * <p>
 * 
 * @author bm
 */
public class KNXIllegalArgumentException extends RuntimeException
{
	private static final long serialVersionUID = 1L;

	private final String arg;

	/**
	 * Constructs a <code>KNXIllegalArgumentException</code> without a detail message.
	 * <p>
	 */
	public KNXIllegalArgumentException()
	{
		arg = null;
	}

	/**
	 * Constructs a <code>KNXIllegalArgumentException</code> with the specified detail
	 * message.
	 * <p>
	 * 
	 * @param s the detail message
	 */
	public KNXIllegalArgumentException(String s)
	{
		super(s);
		arg = null;
	}

	/**
	 * Returns the argument which caused the exception.
	 * <p>
	 * 
	 * @return argument as string, or <code>null</code> if no argument was set
	 */
	public final String getArgument()
	{
		return arg;
	}
}
