/*
  This file is part of Calimero, a pure Java library
  for KNX network access and management.
  http://calimero.sourceforge.net

  Calimero was developed at the Vienna University of Technology,
  Automation Systems Group.
  http://www.auto.tuwien.ac.at/a-lab

  Copyright 2007 Boris Malinowsky

  This version is made available for evaluation purposes only.
  Any commercial use is prohibited. This code is preliminary and
  subject to change at any time without further notice.
  All rights reserved.
*/

/*
 $Log: DisconnectEvent.java,v $
 Revision 1.2  2007/07/20 00:51:57  bm
 review with small updates

 Revision 1.1  2007/02/07 01:59:28  bm
 initial commit

 */

package tuwien.auto.calimero.knxnetip;

import java.util.EventObject;

/**
 * An event providing information regarding the closing of an established KNXnet/IP
 * communication connection.
 * <p>
 */
public class ConnectionCloseEvent extends EventObject
{
	/**
	 * Identifier stating the close event was initiated by the client.
	 * <p>
	 */
	public static final int CLIENT = 0;

	/**
	 * Identifier stating the close event was initiated by the remote endpoint / server.
	 * <p>
	 */
	public static final int SERVER = 1;

	/**
	 * Identifier stating the close event was initiated internal (for example due to an
	 * unsupported protocol version).
	 * <p>
	 */
	public static final int INTERNAL = 2;

	private static final long serialVersionUID = 1L;

	private final int initiator;
	private final String msg;

	/**
	 * Creates a new close event.
	 * <p>
	 * 
	 * @param source the object on which the Event initially occurred
	 * @param initiator initiator of the close event, one of {@link #CLIENT},
	 *        {@link #SERVER} or {@link #INTERNAL}
	 * @param reason brief textual description
	 */
	public ConnectionCloseEvent(Object source, int initiator, String reason)
	{
		super(source);
		this.initiator = initiator;
		msg = reason;
	}

	/**
	 * Returns the initiator of the close event, one of {@link #CLIENT}, {@link #SERVER}
	 * or {@link #INTERNAL}.
	 * <p>
	 * 
	 * @return identifier of the initiator
	 */
	public final int getInitiator()
	{
		return initiator;
	}

	/**
	 * Returns a brief textual description of the closing reason.
	 * <p>
	 * 
	 * @return descriptive message as string
	 */
	public final String getReason()
	{
		return msg;
	}
}
