/*
  This file is part of Calimero, a pure Java library
  for KNX network access and management.
  http://calimero.sourceforge.net

  Calimero was developed at the Vienna University of Technology,
  Automation Systems Group.
  http://www.auto.tuwien.ac.at/a-lab

  Copyright 2007 Boris Malinowsky

  This version is made available for evaluation purposes only.
  Any commercial use is prohibited. This code is preliminary and
  subject to change at any time without further notice.
  All rights reserved.
*/

/*
 $Log: ErrorCodes.java,v $
 Revision 1.1  2007/09/03 22:58:57  bm
 initial commit
 no inheritance of service types from ServiceTypeBase

 */

package tuwien.auto.calimero.knxnetip.servicetype;

/**
 * Contains KNXnet/IP error codes for all supported service types.
 * <p>
 * 
 * @author bm
 */
public final class ErrorCodes
{
	// common error codes

	/**
	 * Error code: Operation successful.
	 * <p>
	 */
	public static final short NO_ERROR = 0x00;

	/**
	 * Error code: The requested type of host protocol is not supported by the device.
	 * <p>
	 */
	public static final short HOST_PROTOCOL_TYPE = 0x01;

	/**
	 * Error code: The requested protocol version is not supported by the device.
	 * <p>
	 */
	public static final short VERSION_NOT_SUPPORTED = 0x02;

	/**
	 * Error code: The received sequence number is out of order.
	 * <p>
	 */
	public static final short SEQUENCE_NUMBER = 0x04;

	// connect response error codes

	/**
	 * Error code: The server does not support the requested connection type.
	 * <p>
	 */
	public static final short CONNECTION_TYPE = 0x22;

	/**
	 * Error code: The server does not support the requested connection options.
	 * <p>
	 */
	public static final short CONNECTION_OPTION = 0x23;

	/**
	 * Error code: The server could not accept a new connection, maximum reached.
	 * <p>
	 */
	public static final short NO_MORE_CONNECTIONS = 0x24;

	/**
	 * Error code: The requested tunneling layer is not supported by the server.
	 * <p>
	 */
	public static final short TUNNELING_LAYER = 0x29;

	// connection state response error codes

	/**
	 * Error code: The server device could not find an active data connection with the
	 * specified ID.
	 * <p>
	 */
	public static final short CONNECTION_ID = 0x21;

	/**
	 * Error code: The server detected an error concerning the data connection with the
	 * specified ID.
	 * <p>
	 */
	public static final short DATA_CONNECTION = 0x26;

	/**
	 * Error code: The server detected an error concerning the KNX subsystem connection
	 * with the specified ID.
	 * <p>
	 */
	public static final short KNX_CONNECTION = 0x27;

	private ErrorCodes()
	{}

	/**
	 * Returns the description message for an error code.
	 * <p>
	 * For now, we only translate common error codes.<br>
	 * On unknown error code, the string "unknown error code" is returned.
	 * 
	 * @param code error code to lookup the description
	 * @return string representation of error code
	 */
	public static String getErrorMessage(int code)
	{
		switch (code) {
		case NO_ERROR:
			return "success";
		case HOST_PROTOCOL_TYPE:
			return "host protocol type not supported";
		case VERSION_NOT_SUPPORTED:
			return "protocol version not supported";
		case SEQUENCE_NUMBER:
			return "sequence number out of order";
		default:
			return "unknown error code";
		}
	}
}
