/*
  This file is part of Calimero, a pure Java library
  for KNX network access and management.
  http://calimero.sourceforge.net

  Calimero was developed at the Vienna University of Technology,
  Automation Systems Group.
  http://www.auto.tuwien.ac.at/a-lab

  Copyright 2007 Boris Malinowsky

  This version is made available for evaluation purposes only.
  Any commercial use is prohibited. This code is preliminary and
  subject to change at any time without further notice.
  All rights reserved.
*/

/*
 $Log$
 */

package tuwien.auto.calimero.knxnetip.servicetype;

import java.io.ByteArrayOutputStream;

import tuwien.auto.calimero.exception.KNXFormatException;

/**
 * Little helpers to handle KNXnet/IP packets and service types.
 * <p>
 * 
 * @author bm
 */
public final class PacketHelper
{
	private PacketHelper()
	{}

	/**
	 * Creates a packet with a KNXnet/IP message header v1.0, containing the specified
	 * service <code>type</code>, and generates the corresponding byte representation
	 * of this structure.
	 * 
	 * @param type service type to pack
	 * @return the packet as byte array
	 */
	public static byte[] toPacket(ServiceType type)
	{
		final KNXnetIPHeader h = new KNXnetIPHeader(type.svcType, type.getStructLength());
		final ByteArrayOutputStream os = new ByteArrayOutputStream(h.getTotalLength());
		os.write(h.toByteArray(), 0, h.getStructLength());
		return type.toByteArray(os);
	}

	public static ServiceRequest getServiceRequest(KNXnetIPHeader h, byte[] data,
		int offset) throws KNXFormatException
	{
		return new ServiceRequest(h.getServiceType(), data, offset, h.getTotalLength()
			- h.getStructLength());
	}
}
