/*
  This file is part of Calimero, a pure Java library
  for KNX network access and management.
  http://calimero.sourceforge.net

  Calimero was developed at the Vienna University of Technology,
  Automation Systems Group.
  http://www.auto.tuwien.ac.at/a-lab

  Copyright 2007 Boris Malinowsky

  This version is made available for evaluation purposes only.
  Any commercial use is prohibited. This code is preliminary and
  subject to change at any time without further notice.
  All rights reserved.
*/

/*
 $Log: ServiceTypeBase.java,v $
 Revision 1.1  2007/09/03 22:58:57  bm
 initial commit
 no inheritance of service types from ServiceTypeBase

 */

package tuwien.auto.calimero.knxnetip.servicetype;

import java.io.ByteArrayOutputStream;

import tuwien.auto.calimero.log.LogManager;
import tuwien.auto.calimero.log.LogService;

/**
 * Common base for the different service type structures.
 * <p>
 * 
 * @author bm
 */
abstract class ServiceType
{
	static final LogService logger = LogManager.getManager().getLogger(
		"KNXnet/IP.servicetype");

	final int svcType;

	ServiceType(int serviceType)
	{
		svcType = serviceType;
	}

	/**
	 * Returns the service type structure formatted into a byte array.
	 * <p>
	 * 
	 * @return service type structure as byte array
	 * @see PacketHelper
	 */
	public final byte[] toByteArray()
	{
		return toByteArray(new ByteArrayOutputStream(50));
	}

	abstract byte[] toByteArray(ByteArrayOutputStream os);

	abstract short getStructLength();
}
