/*
  This file is part of Calimero, a pure Java library
  for KNX network access and management.
  http://calimero.sourceforge.net

  Calimero was developed at the Vienna University of Technology,
  Automation Systems Group.
  http://www.auto.tuwien.ac.at/a-lab

  Copyright 2007 Boris Malinowsky

  This version is made available for evaluation purposes only.
  Any commercial use is prohibited. This code is preliminary and
  subject to change at any time without further notice.
  All rights reserved.
*/

/*
 $Log$
 */

package tuwien.auto.calimero.link;

import tuwien.auto.calimero.link.event.LinkListener;
import tuwien.auto.calimero.link.medium.KNXMediumSettings;

/**
 * @author bm
 */
public interface KNXNetworkMonitor
{
	void setKNXMedium(KNXMediumSettings settings);

	KNXMediumSettings getKNXMedium();

	void setDecodeRawFrames(boolean decode);

	void addMonitorListener(LinkListener l);

	void removeMonitorListener(LinkListener l);

	String getName();

	/**
	 * Ends communication with the KNX network.
	 * <p>
	 * All registered event listeners get notified.<br>
	 * If no communication access was established in the first place, no action is
	 * performed.
	 */
	void close();
	
	/**
	 * Checks for open monitor link.
	 * <p>
	 * After a call to {@link #close()} or after the underlying protocol initiated the end
	 * of the communication, this method always returns <code>false</code>.
	 * 
	 * @return <code>true</code> if this network link is open, <code>false</code> on
	 *         closed
	 */
	boolean isOpen();
}
