/*
  This file is part of Calimero, a pure Java library
  for KNX network access and management.
  http://calimero.sourceforge.net

  Calimero was developed at the Vienna University of Technology,
  Automation Systems Group.
  http://www.auto.tuwien.ac.at/a-lab

  Copyright 2007 Boris Malinowsky

  This version is made available for evaluation purposes only.
  Any commercial use is prohibited. This code is preliminary and
  subject to change at any time without further notice.
  All rights reserved.
*/

/*
 $Log$
 */

package tuwien.auto.calimero.link.medium;

import java.io.ByteArrayInputStream;

import tuwien.auto.calimero.IndividualAddress;
import tuwien.auto.calimero.Priority;
import tuwien.auto.calimero.exception.KNXFormatException;

/**
 * @author bm
 */
public class PL110Frame extends RawFrameBase
{
	private final byte[] doa;

	/**
	 * @throws KNXFormatException
	 */
	public PL110Frame(byte[] data, int offset) throws KNXFormatException
	{
		final ByteArrayInputStream is =
			new ByteArrayInputStream(data, offset, data.length - offset);
		final int ctrl = is.read();
		// parse control field and check if valid
		if ((ctrl & 0x53) != 0x10)
			throw new KNXFormatException("invalid control field", ctrl);
		ext = (ctrl & 0x80) == 0;
		repetition = (ctrl & 0x20) == 0;
		p = Priority.get((ctrl >> 2) & 0x3);

		final int ctrle = ext ? readCtrlEx(is) : 0;
		src = new IndividualAddress((is.read() << 8) | is.read());
		final int addr = (is.read() << 8) | is.read();
		final int npci = is.read();
		final int len;
		if (ext) {
			setDestination(addr, (ctrle & 0x80) != 0);
			len = npci;
			if (len > 64)
				throw new KNXFormatException("APDU length exceeds maximum of 64 bytes",
					len);
		}
		else {
			setDestination(addr, (npci & 0x80) != 0);
			len = npci & 0x0f;
		}

		tpdu = new byte[len + 1];
		is.read(tpdu, 0, tpdu.length);
		fcs = is.read();
		doa = new byte[2];
		is.read(doa, 1, 1);
	}

	public final byte[] getDomainAddress()
	{
		return (byte[]) doa.clone();
	}

	/* (non-Javadoc)
	 * @see tuwien.auto.calimero.link.medium.RawFrameBase#toString()
	 */
	public String toString()
	{
		return super.toString() + " domain " + (doa[1] & 0xff) + ", tpdu " + toHex(tpdu);
	}
}
