/*
  This file is part of Calimero, a pure Java library
  for KNX network access and management.
  http://calimero.sourceforge.net

  Calimero was developed at the Vienna University of Technology,
  Automation Systems Group.
  http://www.auto.tuwien.ac.at/a-lab

  Copyright 2007 Boris Malinowsky

  This version is made available for evaluation purposes only.
  Any commercial use is prohibited. This code is preliminary and
  subject to change at any time without further notice.
  All rights reserved.
*/

/*
 $Log$
 */

package tuwien.auto.calimero.link.medium;


/**
 * @author bm
 */
public class PL132Ack extends RawAckBase
{
	/**
	 * Indicates a negative acknowledge, reception buffer is full.
	 * <p>
	 */
	public static final int FULL = 0x100;

	/**
	 * The kind of acknowledge is unknown, because no checksum from the frame request is
	 * available for comparison, or the delivered checksum in the ack-frame is invalid.
	 * <p>
	 */
	public static final int UNKNOWN_ACK = 0x200;

	private final int fcs;

	public PL132Ack(byte[] data, int offset)
	{
		final int hi = data[offset] & 0xff;
		fcs = hi << 8 | (data[offset + 1] & 0xff);
		ack = UNKNOWN_ACK;
	}

	public PL132Ack(byte[] data, int offset, int requestChecksum)
	{
		final int hi = data[offset] & 0xff;
		fcs = hi << 8 | data[offset + 1] & 0xff;
		if (fcs == requestChecksum)
			ack = ACK;
		else if (((~fcs) & 0xffff) == requestChecksum)
			ack = FULL;
		else
			ack = UNKNOWN_ACK;
	}

	public final int getChecksum()
	{
		return fcs;
	}

	/* (non-Javadoc)
	 * @see tuwien.auto.calimero.link.medium.RawAckBase#toString()
	 */
	public String toString()
	{
		return ack == ACK ? "ACK" : ack == FULL ? "FULL" : "unknown ack";
	}
}
