/*
  This file is part of Calimero, a pure Java library
  for KNX network access and management.
  http://calimero.sourceforge.net

  Calimero was developed at the Vienna University of Technology,
  Automation Systems Group.
  http://www.auto.tuwien.ac.at/a-lab

  Copyright 2007 Boris Malinowsky

  This version is made available for evaluation purposes only.
  Any commercial use is prohibited. This code is preliminary and
  subject to change at any time without further notice.
  All rights reserved.
*/

/*
 $Log$
 */

package tuwien.auto.calimero.link.medium;

import tuwien.auto.calimero.IndividualAddress;
import tuwien.auto.calimero.exception.KNXIllegalArgumentException;

/**
 * @author bm
 */
public class PLSettings extends KNXMediumSettings
{
	private static final byte[] broadcastDomain = new byte[2];
	
	private byte[] doa;
	private final boolean pl132;
	
	/**
	 * @param device
	 */
	public PLSettings(IndividualAddress device, byte[] domain, boolean mediumPL132)
	{
		super(device);
		pl132 = mediumPL132;
		setDomainAddress(domain);
	}

	/**
	 * 
	 */
	public PLSettings(boolean mediumPL132)
	{
		super(null);
		pl132 = mediumPL132;
		doa = broadcastDomain;
	}

	public final synchronized byte[] getDomainAddress()
	{
		return (byte[]) doa.clone();
	}

	public final synchronized void setDomainAddress(final byte[] domain)
	{
		if (domain == null)
			doa = broadcastDomain;
		else if (domain.length != 2)
			throw new KNXIllegalArgumentException("invalid length of domain address");
		else
			doa = (byte[]) domain.clone();
	}
	
	public final boolean isPL132()
	{
		return pl132;
	}

	/* (non-Javadoc)
	 * @see tuwien.auto.calimero.link.medium.KNXMediumSettings#getMediumType()
	 */
	public short getMedium()
	{
		return pl132 ? MEDIUM_PL132 : MEDIUM_PL110;
	}
}
