/*
  This file is part of Calimero, a pure Java library
  for KNX network access and management.
  http://calimero.sourceforge.net

  Calimero was developed at the Vienna University of Technology,
  Automation Systems Group.
  http://www.auto.tuwien.ac.at/a-lab

  Copyright 2007 Boris Malinowsky

  This version is made available for evaluation purposes only.
  Any commercial use is prohibited. This code is preliminary and
  subject to change at any time without further notice.
  All rights reserved.
*/

/*
 $Log$
 */

package tuwien.auto.calimero.link.medium;

import tuwien.auto.calimero.IndividualAddress;
import tuwien.auto.calimero.exception.KNXIllegalArgumentException;

/**
 * @author bm
 */
public class RFSettings extends KNXMediumSettings
{
	private static final byte[] broadcastDomain = new byte[6];

	private byte[] doa;
	private byte[] sno;
	private final boolean unidir;

	/**
	 * 
	 */
	public RFSettings(IndividualAddress device)
	{
		super(device);
		doa = broadcastDomain;
		sno = new byte[6];
		unidir = false;
	}

	public RFSettings(IndividualAddress device, byte[] domain, byte[] serialNumber,
		boolean unidirectional)
	{
		super(device);
		setDomainAddress(domain);
		setSerial(serialNumber);
		unidir = unidirectional;
	}

	public final byte[] getSerialNumber()
	{
		return (byte[]) sno.clone();
	}

	public final synchronized byte[] getDomainAddress()
	{
		return (byte[]) doa.clone();
	}
	
	public final synchronized void setDomainAddress(final byte[] domain)
	{
		if (domain == null)
			doa = broadcastDomain;
		else if (domain.length != 6)
			throw new KNXIllegalArgumentException("invalid length of domain address");
		else
			doa = (byte[]) domain.clone();
	}

	public final boolean isUnidirectional()
	{
		return unidir;
	}
	
	private void setSerial(byte[] serial)
	{
		if (serial.length != 6)
			throw new KNXIllegalArgumentException("invalid length of serial number");
		sno = (byte[]) serial.clone();
	}

	/* (non-Javadoc)
	 * @see tuwien.auto.calimero.link.medium.KNXMediumSettings#getMediumType()
	 */
	public short getMedium()
	{
		return MEDIUM_RF;
	}
}
