/*
  This file is part of Calimero, a pure Java library
  for KNX network access and management.
  http://calimero.sourceforge.net

  Calimero was developed at the Vienna University of Technology,
  Automation Systems Group.
  http://www.auto.tuwien.ac.at/a-lab

  Copyright 2007 Boris Malinowsky

  This version is made available for evaluation purposes only.
  Any commercial use is prohibited. This code is preliminary and
  subject to change at any time without further notice.
  All rights reserved.
*/

/*
 $Log$
 */

package tuwien.auto.calimero.link.medium;

import java.io.ByteArrayInputStream;

import tuwien.auto.calimero.GroupAddress;
import tuwien.auto.calimero.IndividualAddress;
import tuwien.auto.calimero.KNXAddress;
import tuwien.auto.calimero.Priority;
import tuwien.auto.calimero.exception.KNXFormatException;

/**
 * @author bm
 */
public abstract class RawFrameBase implements RawFrame
{
	protected int type = LDATA_FRAME;
	protected IndividualAddress src;
	protected KNXAddress dst;
	protected boolean ext;
	protected boolean repetition;
	protected Priority p;
	protected int fcs;
	// in L-polldata frame tpdu is not used
	protected byte[] tpdu;

	/* (non-Javadoc)
	 * @see tuwien.auto.calimero.link.medium.RawFrame#getFrameType()
	 */
	public final int getFrameType()
	{
		return type;
	}

	public final IndividualAddress getSource()
	{
		return src;
	}

	public final KNXAddress getDestination()
	{
		return dst;
	}

	public final Priority getPriority()
	{
		return p;
	}

	public final boolean isRepetition()
	{
		return repetition;
	}

	public final int getChecksum()
	{
		return fcs;
	}

	public final byte[] getTPDU()
	{
		return tpdu == null ? null : (byte[]) tpdu.clone();
	}

	void setDestination(int addr, boolean group)
	{
		dst = group ? (KNXAddress) new GroupAddress(addr) : new IndividualAddress(addr);
	}

	int readCtrlEx(ByteArrayInputStream is) throws KNXFormatException
	{
		final int ctrle = is.read();
		if ((ctrle & 0xf) != 0)
			throw new KNXFormatException("LTE-HEE frame not supported");
		return ctrle;
	}

	static String toHex(byte[] data)
	{
		if (data.length == 0)
			return "";
		final StringBuffer buf = new StringBuffer();
		for (int i = 0; i < data.length - 1; ++i) {
			final int v = data[i] & 0xff;
			if (v < 0x10)
				buf.append('0');
			buf.append(Integer.toHexString(v)).append(' ');
		}
		buf.append(Integer.toHexString(data[data.length - 1] & 0xff));
		return buf.toString();
	}

	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	public String toString()
	{
		final StringBuffer sb = new StringBuffer();
		sb.append(type == LDATA_FRAME ? "L-Data" : "L-Polldata").append(".req ");
		sb.append(ext ? "(ext)" : "(std)");
		sb.append(" from ").append(src).append(" to ").append(dst);
		sb.append(", ").append(p).append(" priority");
		if (repetition)
			sb.append(" repeat");
		sb.append(" fcs 0x").append(Integer.toHexString(fcs));
		return sb.toString();
	}
}
