/*
  This file is part of Calimero, a pure Java library
  for KNX network access and management.
  http://calimero.sourceforge.net

  Calimero was developed at the Vienna University of Technology,
  Automation Systems Group.
  http://www.auto.tuwien.ac.at/a-lab

  Copyright 2007 Boris Malinowsky

  This version is made available for evaluation purposes only.
  Any commercial use is prohibited. This code is preliminary and
  subject to change at any time without further notice.
  All rights reserved.
*/

/*
 $Log$
 */

package tuwien.auto.calimero.link.medium;

import tuwien.auto.calimero.exception.KNXFormatException;

/**
 * @author bm
 */
public final class RawFrameFactory
{
	private RawFrameFactory()
	{}

	public static RawFrame create(int mediumCode, byte[] data, int offset)
		throws KNXFormatException
	{
		switch (mediumCode) {
		case KNXMediumSettings.MEDIUM_TP0:
			throw new KNXFormatException("TP0 raw frame not supported yet");
		case KNXMediumSettings.MEDIUM_TP1:
			return createTP1(data, offset);
		case KNXMediumSettings.MEDIUM_PL110:
			return createPL110(data, offset);
		case KNXMediumSettings.MEDIUM_PL132:
			return createPL132(data, offset);
		case KNXMediumSettings.MEDIUM_RF:
			throw new KNXFormatException("RF raw frame not supported yet");
		default:
			throw new KNXFormatException("unknown KNX medium for raw frame", mediumCode);
		}
	}

	public static RawFrame createTP1(byte[] data, int offset) throws KNXFormatException
	{
		final int ctrl = data[offset] & 0xff;
		// parse control field and check if valid
		if ((ctrl & 0x10) == 0x10) {
			if ((ctrl & 0x40) == 0x00)
				return new TP1Frame(data, offset);
			else if (ctrl == 0xF0)
				return new TP1LPollData(data, offset);
			throw new KNXFormatException("invalid raw frame control field", ctrl);
		}
		return new TP1Ack(data, offset);
	}

	public static RawFrame createPL110(byte[] data, int offset) throws KNXFormatException
	{
		if ((data[0] & 0x10) == 0x10)
			return new PL110Frame(data, offset);
		return new PL110Ack(data, offset);
	}

	public static RawFrame createPL132(byte[] data, int offset) throws KNXFormatException
	{
		if (data.length - offset == 2)
			return new PL132Ack(data, offset);
		return new PL132Frame(data, offset);
	}
}
