/*
  This file is part of Calimero, a pure Java library
  for KNX network access and management.
  http://calimero.sourceforge.net

  Calimero was developed at the Vienna University of Technology,
  Automation Systems Group.
  http://www.auto.tuwien.ac.at/a-lab

  Copyright 2007 Boris Malinowsky

  This version is made available for evaluation purposes only.
  Any commercial use is prohibited. This code is preliminary and
  subject to change at any time without further notice.
  All rights reserved.
*/

/*
 $Log$
 */

package tuwien.auto.calimero.link.medium;

import tuwien.auto.calimero.exception.KNXFormatException;

/**
 * @author bm
 */
public class TP1Ack extends RawAckBase
{
	public static final int BUSY = 0xC0;
	public static final int NAK_BUSY = 0x00;

	/**
	 * 
	 */
	public TP1Ack(byte[] data, int offset) throws KNXFormatException
	{
		final int ctrl = data[offset] & 0xff;
		if ((ctrl & 0x33) != 0x00)
			throw new KNXFormatException("invalid control field - no TP1 ACK frame", ctrl);
		if (ctrl == ACK)
			ack = ACK;
		else if (ctrl == NAK)
			ack = NAK;
		else if (ctrl == BUSY)
			ack = BUSY;
		else if (ctrl == NAK_BUSY)
			ack = NAK_BUSY;
		else
			throw new KNXFormatException("no valid acknowledge code", ctrl);
	}

	/* (non-Javadoc)
	 * @see tuwien.auto.calimero.link.medium.RawAckBase#toString()
	 */
	public String toString()
	{
		return ack == BUSY ? "BUSY" : ack == NAK_BUSY ? "NAK-BUSY" : super.toString();
	}
}
