/*
  This file is part of Calimero, a pure Java library
  for KNX network access and management.
  http://calimero.sourceforge.net

  Calimero was developed at the Vienna University of Technology,
  Automation Systems Group.
  http://www.auto.tuwien.ac.at/a-lab

  Copyright 2007 Boris Malinowsky

  This version is made available for evaluation purposes only.
  Any commercial use is prohibited. This code is preliminary and
  subject to change at any time without further notice.
  All rights reserved.
*/

/*
 $Log$
 */

package tuwien.auto.calimero.link.medium;

import java.io.ByteArrayInputStream;

import tuwien.auto.calimero.GroupAddress;
import tuwien.auto.calimero.IndividualAddress;
import tuwien.auto.calimero.Priority;
import tuwien.auto.calimero.exception.KNXFormatException;

/**
 * @author bm
 */
public class TP1LPollData extends RawFrameBase
{
	private final int expData;

	/**
	 * @throws KNXFormatException
	 */
	public TP1LPollData(byte[] data, int offset) throws KNXFormatException
	{
		final ByteArrayInputStream is =
			new ByteArrayInputStream(data, offset, data.length - offset);
		final int ctrl = is.read();
		// parse control field and check if valid
		if (ctrl != 0xF0)
			throw new KNXFormatException("invalid control field", ctrl);
		type = LPOLLDATA_FRAME;
		p = Priority.get((ctrl >> 2) & 0x3);
		int addr = (is.read() << 8) | is.read();
		src = new IndividualAddress(addr);
		addr = (is.read() << 8) | is.read();
		dst = new GroupAddress(addr);
		final int len = is.read() & 0x0f;
		expData = len;
		fcs = is.read();
	}

	public final int getExpectedDataLength()
	{
		return expData;
	}

	/* (non-Javadoc)
	 * @see tuwien.auto.calimero.link.medium.RawFrameBase#toString()
	 */
	public String toString()
	{
		return super.toString() + " expected " + expData + " bytes";
	}
}
