/*
  This file is part of Calimero, a pure Java library
  for KNX network access and management.
  http://calimero.sourceforge.net

  Calimero was developed at the Vienna University of Technology,
  Automation Systems Group.
  http://www.auto.tuwien.ac.at/a-lab

  Copyright 2007 Boris Malinowsky

  This version is made available for evaluation purposes only.
  Any commercial use is prohibited. This code is preliminary and
  subject to change at any time without further notice.
  All rights reserved.
*/

/*
 $Log: KNXDisconnectException.java,v $
 Revision 1.1  2007/07/15 00:56:40  bm
 initial commit after package renaming

 Revision 1.2  2007/03/21 00:38:25  bm
 minor stylistic changes

 Revision 1.1  2007/03/20 13:47:28  bm
 Introduced exception hierarchy
 with basic error types

 */

package tuwien.auto.calimero.mgmt;

import tuwien.auto.calimero.exception.KNXException;

/**
 * Thrown to indicate that a disconnect event happened.
 * <p>
 * 
 * @author bm
 */
public class KNXDisconnectException extends KNXException
{
	private static final long serialVersionUID = 1L;

	private final Destination dst;

	/**
	 * Constructs a <code>KNXDisconnectException</code> without a detail message.
	 * <p>
	 */
	public KNXDisconnectException()
	{
		dst = null;
	}

	/**
	 * Constructs a <code>KNXDisconnectException</code> with the specified detail
	 * message.
	 * <p>
	 * 
	 * @param s the detail message
	 */
	public KNXDisconnectException(String s)
	{
		super(s);
		dst = null;
	}

	public KNXDisconnectException(String s, Destination d)
	{
		super(s);
		dst = d;
	}

	public final Destination getDestination()
	{
		return dst;
	}
}
