/*
  This file is part of Calimero, a pure Java library
  for KNX network access and management.
  http://calimero.sourceforge.net

  Calimero was developed at the Vienna University of Technology,
  Automation Systems Group.
  http://www.auto.tuwien.ac.at/a-lab

  Copyright 2007 Boris Malinowsky

  This version is made available for evaluation purposes only.
  Any commercial use is prohibited. This code is preliminary and
  subject to change at any time without further notice.
  All rights reserved.
*/

/*
 $Log$
 */

package tuwien.auto.calimero.mgmt;

import tuwien.auto.calimero.IndividualAddress;
import tuwien.auto.calimero.Priority;
import tuwien.auto.calimero.exception.KNXInvalidResponseException;
import tuwien.auto.calimero.exception.KNXRemoteException;
import tuwien.auto.calimero.exception.KNXTimeoutException;
import tuwien.auto.calimero.link.KNXLinkClosedException;
import tuwien.auto.calimero.link.KNXNetworkLink;

/**
 * @author bm
 */
public interface ManagementClient
{
	/**
	 * doc set the response timeout to wait for a response call to complete
	 * 
	 * @param timeout time in seconds
	 */
	void setResponseTimeout(int timeout);

	int getResponseTimeout();

	void setPriority(Priority p);

	Priority getPriority();

	Destination createDestination(IndividualAddress remote, boolean connectionOriented,
		boolean keepAlive, boolean verifyMode);

	Destination createDestination(IndividualAddress remote, boolean connectionOriented);

	void writeAddress(IndividualAddress addr) throws KNXTimeoutException,
		KNXLinkClosedException;

	void writeAddress(byte[] serialNo, IndividualAddress addr)
		throws KNXTimeoutException, KNXLinkClosedException;

	IndividualAddress[] readAddress(boolean oneAddressOnly) throws KNXTimeoutException,
		KNXRemoteException, KNXLinkClosedException;

	IndividualAddress readAddress(byte[] serialNo) throws KNXTimeoutException,
		KNXRemoteException, KNXLinkClosedException;

	byte[] readMemory(Destination dst, int startAddr, int bytes)
		throws KNXTimeoutException, KNXDisconnectException, KNXRemoteException,
		KNXLinkClosedException;

	void writeMemory(Destination dst, int startAddr, byte[] data)
		throws KNXDisconnectException, KNXTimeoutException, KNXRemoteException,
		KNXLinkClosedException;

	int readADC(Destination dst, int channelNr, int repeat) throws KNXTimeoutException,
		KNXDisconnectException, KNXRemoteException, KNXLinkClosedException;

	byte[] readProperty(Destination dst, int objIndex, int propID, int start, int elements)
		throws KNXTimeoutException, KNXRemoteException, KNXDisconnectException,
		KNXLinkClosedException;

	void writeProperty(Destination dst, int objIndex, int propID, int start,
		int elements, byte[] data) throws KNXTimeoutException, KNXRemoteException,
		KNXDisconnectException, KNXLinkClosedException;

	byte[] readPropertyDesc(Destination dst, int objIndex, int propID, int propIndex)
		throws KNXTimeoutException, KNXRemoteException, KNXDisconnectException,
		KNXLinkClosedException;

	void writeKey(Destination dst, int level, byte[] key) throws KNXTimeoutException,
		KNXDisconnectException, KNXRemoteException, KNXLinkClosedException;

	byte authorize(Destination dst, byte[] key) throws KNXDisconnectException,
		KNXTimeoutException, KNXRemoteException, KNXLinkClosedException;

	void writeDomainAddress(int domain) throws KNXTimeoutException,
		KNXLinkClosedException;

	int[] readDomainAddress(boolean oneAddressOnly) throws KNXLinkClosedException,
		KNXInvalidResponseException, KNXTimeoutException;

	int[] readDomainAddress(int domain, IndividualAddress addr, int range)
		throws KNXInvalidResponseException, KNXLinkClosedException, KNXTimeoutException;

	void restart(Destination dst) throws KNXTimeoutException, KNXLinkClosedException;

	byte[] readDeviceDesc(Destination dst, int descType)
		throws KNXInvalidResponseException, KNXDisconnectException, KNXTimeoutException,
		KNXLinkClosedException;

	boolean isOpen();

	KNXNetworkLink detach();
}
