/*
  This file is part of Calimero, a pure Java library
  for KNX network access and management.
  http://calimero.sourceforge.net

  Calimero was developed at the Vienna University of Technology,
  Automation Systems Group.
  http://www.auto.tuwien.ac.at/a-lab

  Copyright 2007 Boris Malinowsky

  This version is made available for evaluation purposes only.
  Any commercial use is prohibited. This code is preliminary and
  subject to change at any time without further notice.
  All rights reserved.
*/

/*
 $Log: RemotePropertyServiceAdapter.java,v $
 Revision 1.1  2007/08/17 22:34:06  bm
 initial commit

 */

package tuwien.auto.calimero.mgmt;

import tuwien.auto.calimero.IndividualAddress;
import tuwien.auto.calimero.exception.KNXException;
import tuwien.auto.calimero.exception.KNXRemoteException;
import tuwien.auto.calimero.exception.KNXTimeoutException;
import tuwien.auto.calimero.link.KNXLinkClosedException;
import tuwien.auto.calimero.link.KNXNetworkLink;

/**
 * @author bm
 */
public class RemotePropertyServiceAdapter implements PropertyAdapter
{
	private final ManagementClient mc;
	private final boolean close;
	private final Destination dst;
	private final byte[] key;

	public RemotePropertyServiceAdapter(KNXNetworkLink link, boolean closeLink,
		IndividualAddress remote, boolean connOriented) throws KNXLinkClosedException
	{
		mc = new ManagementClientImpl(link);
		close = closeLink;
		dst = mc.createDestination(remote, connOriented);
		key = null;
	}

	public RemotePropertyServiceAdapter(KNXNetworkLink link, boolean closeLink,
		IndividualAddress remote, byte[] authorizeKey) throws KNXException
	{
		mc = new ManagementClientImpl(link);
		close = closeLink;
		dst = mc.createDestination(remote, true);
		key = (byte[]) authorizeKey.clone();
		try {
			mc.authorize(dst, key);
		}
		catch (final KNXException e) {
			final KNXNetworkLink lnk = mc.detach();
			if (close)
				lnk.close();
			throw e;
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see tuwien.auto.calimero.qsl.PropertyAdapter#close()
	 */
	// doc might close link too
	public void close()
	{
		final KNXNetworkLink lnk = mc.detach();
		if (lnk != null && close)
			lnk.close();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see tuwien.auto.calimero.qsl.PropertyAdapter#getPropertyDescription
	 *      (tuwien.auto.calimero.IndividualAddress, int, int, int)
	 */
	public byte[] getDescription(int objIndex, int pid, int propIndex)
		throws KNXTimeoutException, KNXRemoteException, KNXLinkClosedException,
		KNXDisconnectException
	{
		return mc.readPropertyDesc(dst, objIndex, pid, propIndex);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see tuwien.auto.calimero.qsl.PropertyAdapter#getProperty
	 *      (tuwien.auto.calimero.IndividualAddress, int, int, int, int)
	 */
	public byte[] getProperty(int objIndex, int pid, int start, int elements)
		throws KNXTimeoutException, KNXRemoteException, KNXLinkClosedException,
		KNXDisconnectException
	{
		return mc.readProperty(dst, objIndex, pid, start, elements);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see tuwien.auto.calimero.qsl.PropertyAdapter#setProperty
	 *      (tuwien.auto.calimero.IndividualAddress, int, int, int, int, byte[])
	 */
	public void setProperty(int objIndex, int pid, int start, int elements, byte[] data)
		throws KNXTimeoutException, KNXRemoteException, KNXLinkClosedException,
		KNXDisconnectException
	{
		mc.writeProperty(dst, objIndex, pid, start, elements, data);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see tuwien.auto.calimero.qsl.PropertyAdapter#getName()
	 */
	public String getName()
	{
		return "P " + dst.getAddress();
	}

	/* (non-Javadoc)
	 * @see tuwien.auto.calimero.mgmt.PropertyAdapter#isOpen()
	 */
	public boolean isOpen()
	{
		return mc.isOpen();
	}
}
