/*
  This file is part of Calimero, a pure Java library
  for KNX network access and management.
  http://calimero.sourceforge.net

  Calimero was developed at the Vienna University of Technology,
  Automation Systems Group.
  http://www.auto.tuwien.ac.at/a-lab

  Copyright 2007 Boris Malinowsky

  This version is made available for evaluation purposes only.
  Any commercial use is prohibited. This code is preliminary and
  subject to change at any time without further notice.
  All rights reserved.
*/

/*
 $Log: TransportLayer.java,v $
 Revision 1.1  2007/03/02 15:13:18  bm
 introduced osi layer interfaces

 */

package tuwien.auto.calimero.mgmt;

import tuwien.auto.calimero.IndividualAddress;
import tuwien.auto.calimero.KNXAddress;
import tuwien.auto.calimero.Priority;
import tuwien.auto.calimero.exception.KNXTimeoutException;
import tuwien.auto.calimero.link.KNXLinkClosedException;
import tuwien.auto.calimero.link.KNXNetworkLink;

/**
 * @author bm
 */
//doc: - since we do .con implicit through function return, there are no
//listeners and no .con notifications
public interface TransportLayer
{
	Destination createDestination(IndividualAddress remote, boolean connectionOriented);

	Destination createDestination(IndividualAddress remote, boolean connectionOriented,
		boolean keepAlive, boolean verifyMode);

	void destroyDestination(Destination d);
	
	void addTransportListener(TransportListener l);

	void removeTransportListener(TransportListener l);

	void connect(Destination d) throws KNXTimeoutException, KNXLinkClosedException;

	void disconnect(Destination d) throws KNXLinkClosedException;

	// blocking
	void sendData(Destination d, Priority p, byte[] tsdu) throws KNXDisconnectException,
		KNXLinkClosedException;

	// unicast/multicast
	void sendData(KNXAddress addr, Priority p, byte[] tsdu) throws KNXTimeoutException,
		KNXLinkClosedException;

	void broadcast(Priority p, byte[] tsdu) throws KNXTimeoutException,
		KNXLinkClosedException;

	String getName();

	KNXNetworkLink detach();
}
