/*
  This file is part of Calimero, a pure Java library
  for KNX network access and management.
  http://calimero.sourceforge.net

  Calimero was developed at the Vienna University of Technology,
  Automation Systems Group.
  http://www.auto.tuwien.ac.at/a-lab

  Copyright 2007 Boris Malinowsky

  This version is made available for evaluation purposes only.
  Any commercial use is prohibited. This code is preliminary and
  subject to change at any time without further notice.
  All rights reserved.
*/

/*
 $Log$
 */

package tuwien.auto.calimero.process;

import java.util.ArrayList;
import java.util.EventListener;
import java.util.Iterator;
import java.util.List;

import tuwien.auto.calimero.log.LogService;

/**
 * @author bm
 *
 */
final class EventListeners
{
	private final List listeners = new ArrayList();
	private List listenersCopy = new ArrayList();
	private final LogService logger;
	
	EventListeners(LogService logger)
	{
		this.logger = logger;
	}
	
	void add(EventListener l)
	{
		if (l == null)
			return;
		synchronized (listeners) {
			if (!listeners.contains(l)) {
				listeners.add(l);
				listenersCopy = new ArrayList(listeners);
			}
			else
				logger.warn("event listener already registered");
		}
	}
	
	void remove(EventListener l)
	{
		synchronized (listeners) {
			if (listeners.remove(l))
				listenersCopy = new ArrayList(listeners);
		}
	}
	
	Iterator iterator()
	{
		return listenersCopy.iterator();
	}
}
