/*
  This file is part of Calimero, a pure Java library
  for KNX network access and management.
  http://calimero.sourceforge.net

  Calimero was developed at the Vienna University of Technology,
  Automation Systems Group.
  http://www.auto.tuwien.ac.at/a-lab

  Copyright 2007 Boris Malinowsky

  This version is made available for evaluation purposes only.
  Any commercial use is prohibited. This code is preliminary and
  subject to change at any time without further notice.
  All rights reserved.
*/

/*
 $Log: UserLayer.java,v $
 Revision 1.3  2007/03/03 22:09:43  bm
 added some remarks for implementation

 Revision 1.2  2007/03/01 21:02:39  bm
 adapt changes of subclassing KNXAddress

 Revision 1.1  2007/02/07 01:59:28  bm
 initial commit

 */

package tuwien.auto.calimero.process;

import tuwien.auto.calimero.GroupAddress;
import tuwien.auto.calimero.Priority;
import tuwien.auto.calimero.datapoint.Datapoint;
import tuwien.auto.calimero.exception.KNXException;
import tuwien.auto.calimero.exception.KNXFormatException;
import tuwien.auto.calimero.exception.KNXRemoteException;
import tuwien.auto.calimero.exception.KNXTimeoutException;
import tuwien.auto.calimero.link.KNXLinkClosedException;
import tuwien.auto.calimero.link.KNXNetworkLink;

public interface ProcessCommunicator
{
	boolean BOOL_OFF = false;
	boolean BOOL_ON = true;
	boolean BOOL_UP = false;
	boolean BOOL_DOWN = true;
	boolean BOOL_STOP = false;
	boolean BOOL_START = true;

	void setPriority(Priority p);

	Priority getPriority();

	KNXNetworkLink detach();

	void addProcessListener(ProcessListener l);

	void removeProcessListener(ProcessListener l);

	// read write interface
	boolean readBool(GroupAddress addr) throws KNXTimeoutException, KNXRemoteException,
		KNXLinkClosedException, KNXFormatException;

	String readString(GroupAddress addr) throws KNXTimeoutException, KNXRemoteException,
		KNXLinkClosedException, KNXFormatException;

	// degree=2, percent=1 and ucount=(0 and all other)
	short readUnsigned(GroupAddress addr, String format) throws KNXTimeoutException,
		KNXRemoteException, KNXLinkClosedException, KNXFormatException;

	float readFloat(GroupAddress addr) throws KNXTimeoutException, KNXRemoteException,
		KNXLinkClosedException, KNXFormatException;

	byte readControl(GroupAddress addr) throws KNXTimeoutException, KNXRemoteException,
		KNXLinkClosedException, KNXFormatException;

	void write(GroupAddress addr, boolean value) throws KNXTimeoutException,
		KNXLinkClosedException;

	void write(GroupAddress addr, String value) throws KNXTimeoutException,
		KNXFormatException, KNXLinkClosedException;

	// see readUnsigned for scale
	void write(GroupAddress addr, short value, byte scale) throws KNXTimeoutException,
		KNXFormatException, KNXLinkClosedException;

	void write(GroupAddress addr, float value) throws KNXTimeoutException,
		KNXFormatException, KNXLinkClosedException;

	void write(GroupAddress addr, boolean control, byte stepcode)
		throws KNXTimeoutException, KNXFormatException, KNXLinkClosedException;

	String read(Datapoint dp) throws KNXException;

	void write(Datapoint dp, String value) throws KNXException;

	/**
	 * set the read timeout to wait for a read call to complete
	 * 
	 * @param timeout time in seconds
	 */
	void setResponseTimeout(int timeout);

	int getResponseTimeout();
}
