/*
  This file is part of Calimero, a pure Java library
  for KNX network access and management.
  http://calimero.sourceforge.net

  Calimero was developed at the Vienna University of Technology,
  Automation Systems Group.
  http://www.auto.tuwien.ac.at/a-lab

  Copyright 2007 Boris Malinowsky

  This version is made available for evaluation purposes only.
  Any commercial use is prohibited. This code is preliminary and
  subject to change at any time without further notice.
  All rights reserved.
*/

/*
 $Log$
 */

package tuwien.auto.calimero.xml;

/**
 * @author bm
 *
 */
public interface Element
{

	/**
	 * Adds <code>att</code> to the attribute list.
	 * <p>
	 * 
	 * @param a an {@link Attribute}
	 */
	void addAttribute(Attribute a);

	/**
	 * Returns the attribute value of the attribute <code>name</code>.
	 * <p>
	 * 
	 * @param name name of attribute
	 * @return value as String, or "" if <code>name</code> not found
	 */
	String getAttribute(String name);

	/**
	 * Returns the data body of this element as text.
	 * <p>
	 * No formatting is done on the content.
	 * 
	 * @return content as String or <code>null</code> if no data available
	 */
	String getContent();

	/**
	 * Returns if this is an empty element (no content).
	 * <p>
	 * 
	 * @return <code>true</code> if empty, <code>false</code> otherwise
	 */
	boolean isEmptyElement();

	/**
	 * Sets the data body of this element.
	 * <p>
	 * 
	 * @param data data of this element
	 */
	void setContent(String data);

	/**
	 * Determines if this element has a body or not.
	 * <p>
	 * An empty element is of the form
	 * <code>{@literal &lt;element-tag [attributes] /&gt;}</code>.
	 * 
	 */
	void setEmptyElement(boolean empty);

	/**
	 * Returns element name.
	 * <p>
	 * 
	 * @return element name
	 */
	String getName();

}
