/*
  This file is part of Calimero, a pure Java library
  for KNX network access and management.
  http://calimero.sourceforge.net

  Calimero was developed at the Vienna University of Technology,
  Automation Systems Group.
  http://www.auto.tuwien.ac.at/a-lab

  Copyright 2007 Boris Malinowsky

  This version is made available for evaluation purposes only.
  Any commercial use is prohibited. This code is preliminary and
  subject to change at any time without further notice.
  All rights reserved.
*/

/*
 $Log$
 */

package tuwien.auto.calimero.xml;

import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.io.OutputStreamWriter;
import java.io.UnsupportedEncodingException;

/**
 * A XMLWriter and XMLReader is created using its default constructor, i.e. every
 * implementation is required to supply such a constructor.
 * 
 * @author bm
 */
public final class XMLFactory
{
	private static final String DEFAULT_READER =
		"tuwien.auto.calimero.xml.def.DefaultXMLReader";
	private static final String DEFAULT_WRITER =
		"tuwien.auto.calimero.xml.def.DefaultXMLWriter";
	private static final String DEFAULT_RESOLVER =
		"tuwien.auto.calimero.xml.def.DefaultEntityResolver";

	private XMLFactory()
	{}

	public static XMLFactory getInstance()
	{
		return FactoryHolder.f;
	}

	public XMLReader createXMLReader(String systemID) throws KNXMLException
	{
		final XMLReader r = (XMLReader) create(DEFAULT_READER);
		final EntityResolver res = (EntityResolver) create(DEFAULT_RESOLVER);
		final InputStream is = res.resolveInput(systemID);
		try {
			r.setInput(res.getInputReader(is), true);
		}
		catch (final KNXMLException e) {
			try {
				is.close();
			}
			catch (final IOException ignore) {}
			throw e;
		}
		return r;
	}

	public XMLWriter createXMLWriter(String systemID) throws KNXMLException
	{
		final XMLWriter w = (XMLWriter) create(DEFAULT_WRITER);
		final EntityResolver res = (EntityResolver) create(DEFAULT_RESOLVER);
		final OutputStream os = res.resolveOutput(systemID);
		try {
			w.setOutput(new OutputStreamWriter(os, "UTF-8"), true);
			return w;
		}
		catch (final UnsupportedEncodingException e) {
			try {
				os.close();
			}
			catch (final IOException ignore) {}
			throw new KNXMLException("encoding UTF-8 unknown");
		}
	}

	private Object create(String className) throws KNXMLException
	{
		try {
			return Class.forName(className).newInstance();
		}
		catch (final SecurityException e) {
			throw new KNXMLException("loading XML handler not allowed, " + e.getMessage());
		}
		catch (final Exception e) {
			// InstantiationException, IllegalAccessException, ClassNotFoundException
			throw new KNXMLException("failed to create XML handler, " + e.getMessage());
		}
	}

	private static final class FactoryHolder
	{
		static final XMLFactory f = new XMLFactory();

		private FactoryHolder()
		{}
	}
}
