/*
  This file is part of Calimero, a pure Java library
  for KNX network access and management.
  http://calimero.sourceforge.net

  Calimero was developed at the Vienna University of Technology,
  Automation Systems Group.
  http://www.auto.tuwien.ac.at/a-lab

  Copyright 2007 Boris Malinowsky

  This version is made available for evaluation purposes only.
  Any commercial use is prohibited. This code is preliminary and
  subject to change at any time without further notice.
  All rights reserved.
*/

/*
 $Log$
 */

package tuwien.auto.calimero.xml;

import java.io.Reader;

import tuwien.auto.calimero.xml.def.DefaultElement;

/**
 * @author bm
 */
public interface XMLReader
{
	int START_DOC = 1;
	int END_DOC = 2;
	int START_TAG = 3;
	int END_TAG = 4;

	void close() throws KNXMLException;

	/**
	 * Reads input until end of element <code>e</code>.
	 * <p>
	 * All gathered information will be stored into <code>e</code>.
	 * 
	 * @param e the {@link DefaultElement} which should be completed
	 * @throws KNXMLException if end of element is not reachable in xml stream, or end of
	 *         parent element of <code>e</code> was reached
	 */
	void complete(Element e) throws KNXMLException;

	/**
	 * Returns the current element read by the last call of {@link #read()}.
	 * <p>
	 * 
	 * @return current {@link DefaultElement} or <code>null</code> if no element is
	 *         available
	 */
	Element getCurrent();

	int getLineNumber();

	int getPosition();

	/**
	 * Reads in the next recognized element tag.
	 * <p>
	 * If in open elements, they will be discarded.
	 * 
	 * @return the next {@link DefaultElement} or <code>null</code> if no more known
	 *         elements
	 * @throws KNXMLException on read error or malformed XML structure
	 */
	int read() throws KNXMLException;

	void setInput(Reader r, boolean close);
}
