/*
  This file is part of Calimero, a pure Java library
  for KNX network access and management.
  http://calimero.sourceforge.net

  Calimero was developed at the Vienna University of Technology,
  Automation Systems Group.
  http://www.auto.tuwien.ac.at/a-lab

  Copyright 2007 Boris Malinowsky

  This version is made available for evaluation purposes only.
  Any commercial use is prohibited. This code is preliminary and
  subject to change at any time without further notice.
  All rights reserved.
*/

/*
 $Log$
 */

package tuwien.auto.calimero.xml;

import java.io.Writer;
import java.util.List;

/**
 * @author bm
 */
public interface XMLWriter
{
	void close() throws KNXMLException;
	
	/**
	 * Closes the current most inner open element node.
	 * 
	 */
	void endElement() throws KNXMLException;

	/**
	 * Closes all open elements and writes all buffered data to output.
	 * <p>
	 * Call this when finished with writing elements.
	 * 
	 */
	void endAllElements() throws KNXMLException;

	void setOutput(Writer w, boolean close);

	void writeDeclaration(boolean standalone, String encoding) throws KNXMLException;

	/**
	 * Writes a new element.
	 * <p>
	 * Note, if an empty element is written (which has the format &lt;element-name
	 * attribute-list /&gt; ), endElement() must not be called for this element, since it
	 * is ended immediately anyway and not left open.
	 * 
	 * @param name element name of node
	 * @param att list of attributes in start tag
	 * @param content plain text in element node (may be null)
	 */
	void writeElement(String name, List att, String content) throws KNXMLException;

	/**
	 * @param comment
	 * @throws KNXMLException
	 */
	void writeComment(String comment) throws KNXMLException;

	/**
	 * @param name
	 * @param att
	 * @throws KNXMLException
	 */
	void writeEmptyElement(String name, List att) throws KNXMLException;

}
